@@ -29,6 +29,9 @@ See the documentation to initialize your shell: https://ohmyposh.dev/docs/instal
 			"pwsh",
 			"cmd",
 			"nu",
+			"tcsh",
+			"elvish",
+			"xonsh",
 		},
 		Args: NoArgsOrOneValidArg,
 		Run: func(cmd *cobra.Command, args []string) {
@@ -51,12 +54,12 @@ func init() { //nolint:gochecknoinits
 
 func runInit(shellName string) {
 	env := &platform.Shell{
-		Version: cliVersion,
 		CmdFlags: &platform.Flags{
-			Shell:  shellName,
-			Config: config,
-			Strict: strict,
-			Manual: manual,
+			Shell:   shellName,
+			Config:  config,
+			Strict:  strict,
+			Manual:  manual,
+			Version: cliVersion,
 		},
 	}
 	env.Init()
