@@ -24,6 +24,9 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/platform/cmd"
 	"github.com/jandedobbeleer/oh-my-posh/src/regex"
 
+	cpu "github.com/shirou/gopsutil/v3/cpu"
+	disk "github.com/shirou/gopsutil/v3/disk"
+	load "github.com/shirou/gopsutil/v3/load"
 	process "github.com/shirou/gopsutil/v3/process"
 )
 
@@ -67,6 +70,7 @@ type Flags struct {
 	Primary       bool
 	PromptCount   int
 	Cleared       bool
+	Version       string
 }
 
 type CommandError struct {
@@ -87,9 +91,15 @@ type FileInfo struct {
 type Cache interface {
 	Init(home string)
 	Close()
+	// Gets the value for a given key.
+	// Returns the value and a boolean indicating if the key was found.
+	// In case the ttl expired, the function returns false.
 	Get(key string) (string, bool)
-	// ttl in minutes
+	// Sets a value for a given key.
+	// The ttl indicates how may minutes to cache the value.
 	Set(key, value string, ttl int)
+	// Deletes a key from the cache.
+	Delete(key string)
 }
 
 type HTTPRequestModifier func(request *http.Request)
@@ -133,6 +143,30 @@ type Connection struct {
 	SSID         string // Wi-Fi only
 }
 
+type Memory struct {
+	PhysicalTotalMemory     uint64
+	PhysicalAvailableMemory uint64
+	PhysicalFreeMemory      uint64
+	PhysicalPercentUsed     float64
+	SwapTotalMemory         uint64
+	SwapFreeMemory          uint64
+	SwapPercentUsed         float64
+}
+
+type SystemInfo struct {
+	// mem
+	Memory
+	// cpu
+	Times float64
+	CPU   []cpu.InfoStat
+	// load
+	Load1  float64
+	Load5  float64
+	Load15 float64
+	// disk
+	Disks map[string]disk.IOCountersStat
+}
+
 type SegmentsCache map[string]interface{}
 
 func (s *SegmentsCache) Contains(key string) bool {
@@ -150,6 +184,7 @@ type TemplateCache struct {
 	HostName     string
 	Code         int
 	Env          map[string]string
+	Var          map[string]interface{}
 	OS           string
 	WSL          bool
 	PromptCount  int
@@ -218,6 +253,7 @@ type Environment interface {
 	LoadTemplateCache()
 	SetPromptCount()
 	CursorPosition() (row, col int)
+	SystemInfo() (*SystemInfo, error)
 	Debug(message string)
 	Error(err error)
 	Trace(start time.Time, args ...string)
@@ -242,7 +278,7 @@ func (c *commandCache) get(command string) (string, bool) {
 
 type Shell struct {
 	CmdFlags *Flags
-	Version  string
+	Var      map[string]interface{}
 
 	cwd       string
 	cmdCache  *commandCache
@@ -382,6 +418,7 @@ func (env *Shell) HasFiles(pattern string) bool {
 	matches, err := fs.Glob(fileSystem, pattern)
 	if err != nil {
 		env.Error(err)
+		env.Debug("false")
 		return false
 	}
 	for _, match := range matches {
@@ -389,8 +426,10 @@ func (env *Shell) HasFiles(pattern string) bool {
 		if err != nil || file.IsDir() {
 			continue
 		}
+		env.Debug("true")
 		return true
 	}
+	env.Debug("false")
 	return false
 }
 
@@ -400,6 +439,7 @@ func (env *Shell) HasFilesInDir(dir, pattern string) bool {
 	matches, err := fs.Glob(fileSystem, pattern)
 	if err != nil {
 		env.Error(err)
+		env.Debug("false")
 		return false
 	}
 	hasFilesInDir := len(matches) > 0
@@ -740,6 +780,11 @@ func (env *Shell) TemplateCache() *TemplateCache {
 		PromptCount:  env.CmdFlags.PromptCount,
 	}
 	tmplCache.Env = make(map[string]string)
+	tmplCache.Var = make(map[string]interface{})
+
+	if env.Var != nil {
+		tmplCache.Var = env.Var
+	}
 
 	const separator = "="
 	values := os.Environ()
@@ -846,6 +891,39 @@ func (env *Shell) CursorPosition() (row, col int) {
 	return
 }
 
+func (env *Shell) SystemInfo() (*SystemInfo, error) {
+	s := &SystemInfo{}
+
+	mem, err := env.Memory()
+	if err != nil {
+		return nil, err
+	}
+	s.Memory = *mem
+
+	loadStat, err := load.Avg()
+	if err == nil {
+		s.Load1 = loadStat.Load1
+		s.Load5 = loadStat.Load5
+		s.Load15 = loadStat.Load15
+	}
+
+	processorTimes, err := cpu.Percent(0, false)
+	if err == nil && len(processorTimes) > 0 {
+		s.Times = processorTimes[0]
+	}
+
+	processors, err := cpu.Info()
+	if err == nil {
+		s.CPU = processors
+	}
+
+	diskIO, err := disk.IOCounters()
+	if err == nil {
+		s.Disks = diskIO
+	}
+	return s, nil
+}
+
 func IsPathSeparator(env Environment, c uint8) bool {
 	if c == '/' {
 		return true
