@@ -317,3 +317,36 @@ func (env *Shell) isWriteable(folder string) bool {
 	env.Debug("no write access")
 	return false
 }
+
+var (
+	kernel32             = syscall.NewLazyDLL("kernel32.dll")
+	globalMemoryStatusEx = kernel32.NewProc("GlobalMemoryStatusEx")
+)
+
+type memoryStatusEx struct {
+	Length               uint32
+	MemoryLoad           uint32
+	TotalPhys            uint64
+	AvailPhys            uint64
+	TotalPageFile        uint64
+	AvailPageFile        uint64
+	TotalVirtual         uint64
+	AvailVirtual         uint64
+	AvailExtendedVirtual uint64
+}
+
+func (env *Shell) Memory() (*Memory, error) {
+	var memStat memoryStatusEx
+	memStat.Length = uint32(unsafe.Sizeof(memStat))
+	r0, _, err := globalMemoryStatusEx.Call(uintptr(unsafe.Pointer(&memStat)))
+	if r0 == 0 {
+		env.Error(err)
+		return nil, err
+	}
+	return &Memory{
+		PhysicalTotalMemory:     memStat.TotalPhys,
+		PhysicalFreeMemory:      memStat.AvailPhys,
+		PhysicalAvailableMemory: memStat.AvailPhys,
+		PhysicalPercentUsed:     float64(memStat.MemoryLoad),
+	}, nil
+}
