@@ -597,6 +597,7 @@ func TestGitUpstream(t *testing.T) {
 	}{
 		{Case: "No upstream", Expected: "", Upstream: ""},
 		{Case: "SSH url", Expected: "G", Upstream: "ssh://git@git.my.domain:3001/ADIX7/dotconfig.git"},
+		{Case: "Gitea", Expected: "EX", Upstream: "_gitea@src.example.com:user/repo.git"},
 		{Case: "GitHub", Expected: "GH", Upstream: "github.com/test"},
 		{Case: "Gitlab", Expected: "GL", Upstream: "gitlab.com/test"},
 		{Case: "Bitbucket", Expected: "BB", Upstream: "bitbucket.org/test"},
@@ -619,6 +620,7 @@ func TestGitUpstream(t *testing.T) {
 			GitIcon:         "G",
 			UpstreamIcons: map[string]string{
 				"mycustom.server": "CU",
+				"src.example.com": "EX",
 			},
 		}
 		g := &Git{
