@@ -11,6 +11,7 @@ import (
 
 	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
+	"github.com/jandedobbeleer/oh-my-posh/src/upgrade"
 )
 
 //go:embed scripts/omp.ps1
@@ -31,6 +32,15 @@ var cmdInit string
 //go:embed scripts/omp.nu
 var nuInit string
 
+//go:embed scripts/omp.tcsh
+var tcshInit string
+
+//go:embed scripts/omp.elv
+var elvishInit string
+
+//go:embed scripts/omp.py
+var xonshInit string
+
 const (
 	noExe = "echo \"Unable to find Oh My Posh executable\""
 )
@@ -153,7 +163,7 @@ func quoteNuStr(str string) string {
 func Init(env platform.Environment) string {
 	shell := env.Flags().Shell
 	switch shell {
-	case PWSH, PWSH5:
+	case PWSH, PWSH5, ELVISH:
 		executable, err := getExecutablePath(env)
 		if err != nil {
 			return noExe
@@ -165,9 +175,17 @@ func Init(env platform.Environment) string {
 		if env.Flags().Manual {
 			additionalParams += " --manual"
 		}
-		command := "(@(& %s init %s --config=%s --print%s) -join \"`n\") | Invoke-Expression"
-		return fmt.Sprintf(command, quotePwshStr(executable), shell, quotePwshStr(env.Flags().Config), additionalParams)
-	case ZSH, BASH, FISH, CMD:
+		var command, config string
+		switch shell {
+		case PWSH, PWSH5:
+			command = "(@(& %s init %s --config=%s --print%s) -join \"`n\") | Invoke-Expression"
+			config = quotePwshStr(env.Flags().Config)
+		case ELVISH:
+			command = "eval (%s init %s --config=%s --print%s | slurp)"
+			config = quotePosixStr(env.Flags().Config)
+		}
+		return fmt.Sprintf(command, quotePwshStr(executable), shell, config, additionalParams)
+	case ZSH, BASH, FISH, CMD, TCSH, XONSH:
 		return PrintInit(env)
 	case NU:
 		createNuInit(env)
@@ -218,9 +236,22 @@ func PrintInit(env platform.Environment) string {
 		executable = quoteNuStr(executable)
 		configFile = quoteNuStr(configFile)
 		script = nuInit
+	case TCSH:
+		executable = quotePosixStr(executable)
+		configFile = quotePosixStr(configFile)
+		script = tcshInit
+	case ELVISH:
+		executable = quotePosixStr(executable)
+		configFile = quotePosixStr(configFile)
+		script = elvishInit
+	case XONSH:
+		executable = quotePosixStr(executable)
+		configFile = quotePosixStr(configFile)
+		script = xonshInit
 	default:
 		return fmt.Sprintf("echo \"No initialization script available for %s\"", shell)
 	}
+	notice, hasNotice := upgrade.Notice(env)
 	return strings.NewReplacer(
 		"::OMP::", executable,
 		"::CONFIG::", configFile,
@@ -230,6 +261,8 @@ func PrintInit(env platform.Environment) string {
 		"::TOOLTIPS::", toggleSetting(Tooltips),
 		"::RPROMPT::", strconv.FormatBool(RPrompt),
 		"::CURSOR::", strconv.FormatBool(Cursor),
+		"::UPGRADE::", strconv.FormatBool(hasNotice),
+		"::UPGRADENOTICE::", notice,
 	).Replace(script)
 }
 
