@@ -7,6 +7,9 @@ func interFaceToInt(e interface{}) int {
 	if val, OK := e.(float64); OK {
 		return int(val)
 	}
+	if val, OK := e.(int64); OK {
+		return int(val)
+	}
 	return 0
 }
 
@@ -17,6 +20,9 @@ func interfaceToFloat64(e interface{}) float64 {
 	if val, OK := e.(int); OK {
 		return float64(val)
 	}
+	if val, OK := e.(int64); OK {
+		return float64(val)
+	}
 	return 0
 }
 
@@ -31,5 +37,5 @@ func gt(e1, e2 interface{}) bool {
 }
 
 func lt(e1, e2 interface{}) bool {
-	return !gt(e1, e2)
+	return gt(e2, e1)
 }
