@@ -67,6 +67,7 @@ module.exports = {
         "segments/crystal",
         "segments/dart",
         "segments/deno",
+        "segments/docker",
         "segments/dotnet",
         "segments/elixir",
         "segments/executiontime",
@@ -103,6 +104,7 @@ module.exports = {
         "segments/root",
         "segments/ruby",
         "segments/rust",
+        "segments/sapling",
         "segments/session",
         "segments/shell",
         "segments/spotify",
@@ -114,6 +116,7 @@ module.exports = {
         "segments/text",
         "segments/time",
         "segments/ui5tooling",
+        "segments/unity",
         "segments/vala",
         "segments/wakatime",
         "segments/withings",
